monkey.metrics.otlp

OpenTelemetry client implementation, used to push metrics to an OTLP collector endpoint, in cases scraping is not possible.

OpenTelemetry client implementation, used to push metrics to an OTLP 
collector endpoint, in cases scraping is not possible.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries