monkey.metrics.prometheus


counter-getclj

(counter-get c & [label-vals])
source

counter-incclj

(counter-inc c v & [label-vals])
source

gauge-decclj

(gauge-dec g & [n])
source

gauge-getclj

(gauge-get g)
source

gauge-incclj

(gauge-inc g & [n])
source

gauge-setclj

(gauge-set g v)
source

make-counterclj

(make-counter name reg & [opts])
source

make-gaugeclj

(make-gauge name reg & [opts])
source

make-registryclj

(make-registry)

Creates a new prometheus registry

Creates a new prometheus registry
sourceraw docstring

scrapeclj

(scrape reg)

Returns metrics formatted to Prometheus scrape format as a string.

Returns metrics formatted to Prometheus scrape format as a string.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries