OpenTelemetry client implementation, used to push metrics to an OTLP collector endpoint, in cases scraping is not possible.
OpenTelemetry client implementation, used to push metrics to an OTLP collector endpoint, in cases scraping is not possible.
(make-client url reg {:keys [headers interval service labels version]})Creates a new OTLP client that pushes to given url, using metrics from the
specified Prometheus registry. The client automatically pushes metrics
data at configured intervals (by default 60 seconds). Note that even though
most options are not required here, they may be required by the endpoint
(such as version).
Creates a new OTLP client that pushes to given url, using metrics from the specified Prometheus registry. The client automatically pushes metrics data at configured intervals (by default 60 seconds). Note that even though most options are not required here, they may be required by the endpoint (such as `version`).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |