(make-registry)Creates a new prometheus registry
Creates a new prometheus registry
(scrape reg)Returns metrics formatted to Prometheus scrape format as a string.
Returns metrics formatted to Prometheus scrape format as a string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |